@@ -4,7 +4,7 @@ import re
 import matplotlib.pyplot as plt
 from variable_lib_drturtle.variables import *
 from dataclasses import dataclass
-from typing import Any
+from typing import Any, List
 
 U_RE = re.compile(r"^(?P<name>.+?)(?:\((?P<unit>.+)\))?$", flags=re.MULTILINE)
 
@@ -40,6 +40,9 @@ class Value1D:
     def __getitem__(self, key: int):
         return self.values[key]
 
+    def __len__(self):
+        return len(self.values)
+
 
 class VariableList2D:
     def __init__(self, name: str, initial: np.ndarray):
